@@ -21,11 +21,11 @@ pub fn get_config_authors(vcs: &dyn Vcs) -> Result<Authors, VcsError> {
             let initial = String::from(*fragment_iterator.next().unwrap());
             let part = String::from(*fragment_iterator.next().unwrap());
 
-            let mut exisiting: BTreeMap<String, String> =
+            let mut existing: BTreeMap<String, String> =
                 acc.get(&initial).map(BTreeMap::clone).unwrap_or_default();
-            exisiting.insert(part, String::from(vcs.get_str(key)?.unwrap()));
+            existing.insert(part, String::from(vcs.get_str(key)?.unwrap()));
 
-            acc.insert(initial, exisiting);
+            acc.insert(initial, existing);
             Ok(acc)
         })?;
 
@@ -61,8 +61,6 @@ pub fn get_config_authors(vcs: &dyn Vcs) -> Result<Authors, VcsError> {
 mod tests {
     use std::collections::BTreeMap;
 
-    use pretty_assertions::assert_eq;
-
     use crate::mit::cmd::get_config_authors::get_config_authors;
     use crate::mit::Authors;
     use crate::{external::InMemory, mit::Author};
